<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>AddPluginDialog</name>
    <message>
        <location filename="../config/addplugindialog.ui" line="14"/>
        <source>Add Plugins</source>
        <translation>Добавить плагины</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="22"/>
        <source>Search:</source>
        <translation>Найти:</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="102"/>
        <source>Add Widget</source>
        <translation>Добавить виджет</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.ui" line="112"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../config/addplugindialog.cpp" line="115"/>
        <source>(only one instance can run at a time)</source>
        <translation>(только одна копия может быть запущена за раз)</translation>
    </message>
</context>
<context>
    <name>ConfigPanelDialog</name>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="31"/>
        <source>Configure Panel</source>
        <translation>Настроить панель</translation>
    </message>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="39"/>
        <source>Placement</source>
        <translation>Расположение</translation>
    </message>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="43"/>
        <source>Styling</source>
        <translation>Оформление</translation>
    </message>
    <message>
        <location filename="../config/configpaneldialog.cpp" line="47"/>
        <source>Widgets</source>
        <translation>Виджеты</translation>
    </message>
</context>
<context>
    <name>ConfigPlacement</name>
    <message>
        <location filename="../config/configplacement.ui" line="20"/>
        <source>Configure Placement</source>
        <translation>Настроить расположение</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="44"/>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="68"/>
        <source>&lt;p&gt;Negative pixel value sets the panel length to that many pixels less than available screen space.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;E.g. &quot;Length&quot; set to -100px, screen size is 1000px, then real panel length will be 900 px.&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;Отрицательное число пикселей устанавливает длину панели на это количество пикселей меньше, чем доступное место экрана.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;Например, «Длина» выставлена на -100 пикс, размер экрана 1000 пикс, тогда реальная длина панели будет 900 пикс.&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="81"/>
        <source>Size:</source>
        <translation>Размер:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="88"/>
        <source>Length:</source>
        <translation>Длина:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="96"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="101"/>
        <source>px</source>
        <translation>пикс</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="109"/>
        <location filename="../config/configplacement.ui" line="153"/>
        <source> px</source>
        <translation> пикс</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="166"/>
        <source>Icon size:</source>
        <translation>Размер значков:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="173"/>
        <source>Rows:</source>
        <translation>Ряды:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="202"/>
        <source>Alignment &amp;&amp; position</source>
        <translation>Выравнивание и расположение</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="208"/>
        <source>Alignment:</source>
        <translation>Выравнивание:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="219"/>
        <location filename="../config/configplacement.cpp" line="188"/>
        <source>Left</source>
        <translation>Слева</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="224"/>
        <location filename="../config/configplacement.cpp" line="189"/>
        <location filename="../config/configplacement.cpp" line="195"/>
        <source>Center</source>
        <translation>По центру</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="229"/>
        <location filename="../config/configplacement.cpp" line="190"/>
        <source>Right</source>
        <translation>Справа</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="237"/>
        <source>Position:</source>
        <translation>Расположение:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="250"/>
        <source>A&amp;uto-hide</source>
        <translation>&amp;Автоматически скрывать</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="262"/>
        <location filename="../config/configplacement.ui" line="285"/>
        <source>Zero means no animation</source>
        <translation>Ноль означает отсутствие анимации</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="265"/>
        <source>Animation duration:</source>
        <translation>Длительность анимации:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="288"/>
        <location filename="../config/configplacement.ui" line="314"/>
        <source> ms</source>
        <translation> мс</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="301"/>
        <location filename="../config/configplacement.ui" line="311"/>
        <source>Zero means no delay</source>
        <translation>Ноль означает отсутствие задержки</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="304"/>
        <source>Show with delay:</source>
        <translation>Показывать с задержкой:</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="327"/>
        <source>Visible thin margin for hidden panel</source>
        <translation>Оставлять тонкую видимую полосу при скрытии панели</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="334"/>
        <source>Hide only on overlapping a window</source>
        <translation>Скрывать только при перекрытии окном</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="344"/>
        <source>Don&apos;t allow maximized windows go under the panel window</source>
        <translation>Не позволять развёрнутым окнам залезать под панель</translation>
    </message>
    <message>
        <location filename="../config/configplacement.ui" line="347"/>
        <source>Reserve space on display</source>
        <translation>Зарезервировать место на экране</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="154"/>
        <source>Top of screen</source>
        <translation>Верхняя часть экрана</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="155"/>
        <source>Left of screen</source>
        <translation>Левая часть экрана</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="156"/>
        <source>Right of screen</source>
        <translation>Правая часть экрана</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="157"/>
        <source>Bottom of screen</source>
        <translation>Нижняя часть экрана</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="166"/>
        <source>Top of screen %1</source>
        <translation>Верхняя часть экрана%1</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="167"/>
        <source>Left of screen %1</source>
        <translation>Левая часть экрана%1</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="168"/>
        <source>Right of screen %1</source>
        <translation>Правая часть экрана%1</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="169"/>
        <source>Bottom of screen %1</source>
        <translation>Нижняя часть экрана%1</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="194"/>
        <source>Top</source>
        <translation>Вверху</translation>
    </message>
    <message>
        <location filename="../config/configplacement.cpp" line="196"/>
        <source>Bottom</source>
        <translation>Внизу</translation>
    </message>
</context>
<context>
    <name>ConfigPluginsWidget</name>
    <message>
        <location filename="../config/configpluginswidget.ui" line="14"/>
        <source>Configure Plugins</source>
        <translation>Настроить плагины</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="84"/>
        <source>Note: changes made in this page cannot be reset.</source>
        <translation>Примечание: изменения, сделанные на этой вкладке, нельзя сбросить.</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="112"/>
        <source>Move up</source>
        <translation>Переместить выше</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="115"/>
        <location filename="../config/configpluginswidget.ui" line="129"/>
        <location filename="../config/configpluginswidget.ui" line="150"/>
        <location filename="../config/configpluginswidget.ui" line="164"/>
        <location filename="../config/configpluginswidget.ui" line="185"/>
        <source>...</source>
        <translation>…</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="126"/>
        <source>Move down</source>
        <translation>Переместить ниже</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="147"/>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="161"/>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../config/configpluginswidget.ui" line="182"/>
        <source>Configure</source>
        <translation>Настроить</translation>
    </message>
</context>
<context>
    <name>ConfigStyling</name>
    <message>
        <location filename="../config/configstyling.ui" line="20"/>
        <source>Configure Styling</source>
        <translation>Настроить оформление</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="44"/>
        <source>Custom styling</source>
        <translation>Пользовательский стиль</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="65"/>
        <source>Font color:</source>
        <translation>Цвет шрифта:</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="105"/>
        <source>Background color:</source>
        <translation>Цвет фона:</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="144"/>
        <source>Background opacity:</source>
        <translation>Непрозрачность фона:</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="176"/>
        <source>&lt;small&gt;Compositing is required for panel transparency.&lt;/small&gt;</source>
        <translation>&lt;small&gt;Композиция необходима для прозрачности панели.&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="204"/>
        <source>Background image:</source>
        <translation>Фоновое изображение:</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="256"/>
        <source>A partial workaround for widget styles that
cannot give a separate theme to the panel.

You might also want to disable:

LXQt Appearance Configuration →
Icons Theme →
Colorize icons based on widget style (palette)</source>
        <translation>Частичное обходное решение для стилей виджетов,
которые не устанавливают отдельную тему для панели.

Вы также возможно захотите отключить:

Настройка внешнего вида LXQt →
Тема значков →
Цвет значков в соответствии с палитрой виджетов</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="266"/>
        <source>Override icon &amp;theme</source>
        <translation>Переопределить &amp;тему значков</translation>
    </message>
    <message>
        <location filename="../config/configstyling.ui" line="281"/>
        <source>Icon theme for panels:</source>
        <translation>Тема значков панелей:</translation>
    </message>
    <message>
        <location filename="../config/configstyling.cpp" line="189"/>
        <location filename="../config/configstyling.cpp" line="205"/>
        <source>Pick color</source>
        <translation>Выбрать цвет</translation>
    </message>
    <message>
        <location filename="../config/configstyling.cpp" line="223"/>
        <source>Pick image</source>
        <translation>Выберите изображение</translation>
    </message>
    <message>
        <location filename="../config/configstyling.cpp" line="223"/>
        <source>Images (*.png *.gif *.jpg *.svg)</source>
        <translation>Изображения (*.png *.gif *.jpg *.svg)</translation>
    </message>
</context>
<context>
    <name>LXQtPanel</name>
    <message>
        <location filename="../lxqtpanel.cpp" line="1495"/>
        <location filename="../lxqtpanel.cpp" line="1521"/>
        <source>Panel</source>
        <translation>Панель</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1524"/>
        <source>Configure Panel</source>
        <translation>Настроить панель</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1529"/>
        <source>Manage Widgets</source>
        <translation>Управление виджетами</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1535"/>
        <source>Add New Panel</source>
        <translation>Добавить новую панель</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1542"/>
        <source>Remove Panel</source>
        <comment>Menu Item</comment>
        <translation>Удалить панель</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1547"/>
        <source>Lock This Panel</source>
        <translation>Закрепить панель</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1710"/>
        <source>Remove Panel</source>
        <comment>Dialog Title</comment>
        <translation>Удалить панель</translation>
    </message>
    <message>
        <location filename="../lxqtpanel.cpp" line="1711"/>
        <source>Removing a panel can not be undone.
Do you want to remove this panel?</source>
        <translation>Удаление панели не может быть отменено.
Вы хотите удалить эту панель?</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../plugin.cpp" line="455"/>
        <source>Configure &quot;%1&quot;</source>
        <translation>Настроить «%1»</translation>
    </message>
    <message>
        <location filename="../plugin.cpp" line="460"/>
        <source>Move &quot;%1&quot;</source>
        <translation>Переместить «%1»</translation>
    </message>
    <message>
        <location filename="../plugin.cpp" line="468"/>
        <source>Remove &quot;%1&quot;</source>
        <translation>Удалить «%1»</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../lxqtpanelapplication.cpp" line="340"/>
        <source>Use alternate configuration file.</source>
        <translation>Использовать альтернативный файл настроек.</translation>
    </message>
    <message>
        <location filename="../lxqtpanelapplication.cpp" line="341"/>
        <source>Configuration file</source>
        <translation>Файл настроек</translation>
    </message>
</context>
</TS>
